American Buffalo: David Mamet, Gregory Mosher: 9780802150578: Amazon.com: Books
Description: American Buffalo [David Mamet, Gregory Mosher] on Amazon.com. *FREE* shipping on qualifying offers. American Buffalo

Skip to main content
Add Prime to get Fast, Free delivery

# Amazon Prime Free Trial

FREE Delivery is available to Prime members. To join, select "Try Amazon Prime and start saving today with FREE Delivery" below the Add to Cart button and confirm your Prime free trial.

Amazon Prime members enjoy:

- Cardmembers earn 5% Back at Amazon.com with a Prime Credit Card.
- Unlimited FREE Prime delivery
- Streaming of thousands of movies and TV shows with limited ads on Prime Video.
- A Kindle book to borrow for free each month - with no due dates
- Listen to over 2 million songs and hundreds of playlists

Important: Your credit card will NOT be charged when you start your free trial or if you cancel during the trial period. If you're happy with Amazon Prime, do nothing. At the end of the free trial, your membership will automatically upgrade to a monthly membership.

Kindle
$8.54
Available instantly
Audiobook
$0.00
with membership trial
Paperback
$8.99

Other Used, New, Collectible from $1.92
Paperback from $1.92

- Delivery
- Pickup

#####
Buy new:
-44% $8.99$8.99
FREE delivery Monday, December 30 on orders shipped by Amazon over $35
Ships from: Amazon.com
Sold by: Amazon.com

$8.99 with 44 percent savings -44% $8.99
List Price: $16.00 List Price: $16.00$16.00
The List Price is the suggested retail price of a new product as provided by a manufacturer, supplier, or seller. Except for books, Amazon will display a List Price if the product was purchased by customers on Amazon or offered by other retailers at or above the List Price in at least the past 90 days. List prices may not necessarily reflect the product's prevailing market price.
Learn more
Get Fast, Free Shipping with Amazon Prime FREE Returns

##### Return this item for free

We offer easy, convenient returns with at least one free return option: no shipping charges. All returns must comply with our returns policy.

Learn more about free returns.
How to return the item?

1. Go to your orders and start the return
2. Select your preferred free shipping option
3. Drop off and leave!

FREE delivery Monday, December 30 on orders shipped by Amazon over $35
Or Prime members get FREE delivery Sunday, December 22. Order within 9 hrs 51 mins. Join Prime
Arrives before Christmas
Delivering to Vancouver 98665 - Update location
In Stock
Quantity:
Quantity:1
$$8.998.99 () Includes selected options. Includes initial monthly payment and selected options. Details
Price ($8.99x)
$8.99

Subtotal
$$8.998.99
Subtotal

Initial payment breakdown

Shipping cost, delivery date, and order total (including tax) shown at checkout.
Add to Cart
Buy Now
Ships from
Amazon.com
Amazon.com
Ships from
Amazon.com
Sold by
Amazon.com
Amazon.com
Sold by
Amazon.com
Returns
Returnable until Jan 31, 2025
Returnable until Jan 31, 2025
For the 2024 holiday season, eligible items purchased between November 1 and December 31, 2024 can be returned until January 31, 2025.
Read full return policy
Payment
Secure transaction
Your transaction is secure
We work hard to protect your security and privacy. Our payment security system encrypts your information during transmission. We don’t share your credit card details with third-party sellers, and we don’t sell your information to others. Learn more
See more
Add a gift receipt for easy returns

#####
Save with Used - Good
$6.01$6.01
FREE delivery Monday, December 30 on orders shipped by Amazon over $35
Ships from: Amazon
Sold by: Zoom Books Company

$6.01 $6.01
Get Fast, Free Shipping with Amazon Prime FREE Returns

##### Return this item for free

We offer easy, convenient returns with at least one free return option: no shipping charges. All returns must comply with our returns policy.

Learn more about free returns.
How to return the item?

1. Go to your orders and start the return
2. Select your preferred free shipping option
3. Drop off and leave!

Book is in good condition and may include underlining highlighting and minimal wear. The book can also include "From the library of" labels. May not contain miscellaneous items toys, dvds, etc. . We offer 100% money back guarantee and 24 7 customer service. Free 2-day shipping with Amazon Prime! Book is in good condition and may include underlining highlighting and minimal wear. The book can also include "From the library of" labels. May not contain miscellaneous items toys, dvds, etc. . We offer 100% money back guarantee and 24 7 customer service. Free 2-day shipping with Amazon Prime! Book is in good condition and may include underlining highlighting and minimal wear. The book can also include "From the library of" labels. May not contain miscellaneous items toys, dvds, etc. . We offer 100% money back guarantee and 24 7 customer service. Free 2-day shipping with Amazon Prime! See less
FREE delivery Monday, December 30 on orders shipped by Amazon over $35
Or Prime members get FREE delivery Monday, December 23. Order within 9 hrs 51 mins. Join Prime
Arrives before Christmas
Delivering to Vancouver 98665 - Update location
Only 1 left in stock - order soon.
$$8.998.99 () Includes selected options. Includes initial monthly payment and selected options. Details
Price ($8.99x)
$8.99

Subtotal
$$8.998.99
Subtotal

Initial payment breakdown

Shipping cost, delivery date, and order total (including tax) shown at checkout.
Access codes and supplements are not guaranteed with used items.
Add to Cart
Enhancements you chose aren't available for this seller. Details
To add the following enhancements to your purchase, choose a different seller.

%cardName%
${cardName} not available for the seller you chose
${cardName} unavailable for quantities greater than ${maxQuantity}.
Sold by Zoom Books Company and Fulfilled by Amazon.

Add to List
Added to
Unable to add item to List. Please try again.

### Sorry, there was a problem.

There was an error retrieving your Wish Lists. Please try again.

### Sorry, there was a problem.

List unavailable.
$8.99 with 44 percent savings -44% $8.99
List Price: $16.00 List Price: $16.00$16.00
The List Price is the suggested retail price of a new product as provided by a manufacturer, supplier, or seller. Except for books, Amazon will display a List Price if the product was purchased by customers on Amazon or offered by other retailers at or above the List Price in at least the past 90 days. List prices may not necessarily reflect the product's prevailing market price.
Learn more
FREE pickup Friday, December 27 on orders shipped by Amazon over $35
Or Prime members get FREE pickup Monday, December 23. Order within 9 hrs 51 mins. Join Prime
Amazon Counter - Postal Connections (PUDO)

1.23 mi | Vancouver 98665

How pickup works
Pick up from nearby pickup location
Step 1: Place Your Order
Select the “Pickup” option on the product page or during checkout.
Step 2: Receive Notification
Once your package is ready for pickup, you'll receive an email and app notification.
Step 3: Pick up
Bring your order ID or pickup code (if applicable) to your chosen pickup location to pick up your package.
In Stock
Quantity:
Quantity:1
$$8.998.99 () Includes selected options. Includes initial monthly payment and selected options. Details
Price ($8.99x)
$8.99

Subtotal
$$8.998.99
Subtotal

Initial payment breakdown

Shipping cost, delivery date, and order total (including tax) shown at checkout.
Add to Cart
Buy Now
Enhancements you chose aren't available for this seller. Details
To add the following enhancements to your purchase, choose a different seller.

%cardName%
${cardName} not available for the seller you chose
${cardName} unavailable for quantities greater than ${maxQuantity}.
Sold by
Amazon.com
Amazon.com
Sold by
Amazon.com
Returns
Returnable until Jan 31, 2025
Returnable until Jan 31, 2025
For the 2024 holiday season, eligible items purchased between November 1 and December 31, 2024 can be returned until January 31, 2025.
Read full return policy
Payment
Secure transaction
Your transaction is secure
We work hard to protect your security and privacy. Our payment security system encrypts your information during transmission. We don’t share your credit card details with third-party sellers, and we don’t sell your information to others. Learn more
See more
Other sellers on Amazon

New & Used (73) from $1.92$1.92 + $3.98 shipping
Sponsored

Download the free Kindle app and start reading Kindle books instantly on your smartphone, tablet, or computer - no Kindle device required.

Read instantly on your browser with Kindle for Web.

Using your mobile phone camera - scan the code below and download the Kindle app.

#### Image Unavailable

Image not available for
Color:

- To view this video download Flash Player

Roll over image to zoom in

- VIDEOS
- 360° VIEW
- IMAGES

Audible sample
0:00

# Follow the author

David MametDavid Mamet
Follow
Something went wrong. Please try your request again later.

OK

# American Buffalo Paperback – January 11, 1994

by David Mamet (Author), Gregory Mosher (Introduction)
4.2 4.2 out of 5 stars 101 ratings
See all formats and editions
Sorry, there was a problem loading this page. Try again.

{"desktop_buybox_group_1":[{"displayPrice":"$8.99","priceAmount":8.99,"currencySymbol":"$","integerValue":"8","decimalSeparator":".","fractionalValue":"99","symbolPosition":"left","hasSpace":false,"showFractionalPartIfEmpty":true,"offerListingId":"FPAgLD8jls34W7ARk0Aginh57a4wfKPHs%2FH1cJNhB07JrJLEFV65U373D8W3yJP6GyX2EvrpIWhVkR0wt3XoQNMM8gcACaHqFKaDcmUBfrep1QcAJl6rfzkcV0W71ThL23p7A6BsmaA%3D","locale":"en-US","buyingOptionType":"NEW","aapiBuyingOptionIndex":0}, {"displayPrice":"$6.01","priceAmount":6.01,"currencySymbol":"$","integerValue":"6","decimalSeparator":".","fractionalValue":"01","symbolPosition":"left","hasSpace":false,"showFractionalPartIfEmpty":true,"offerListingId":"FPAgLD8jls34W7ARk0Aginh57a4wfKPH%2BXWsgZHFJoSxYrKdnxxGNRy%2BaWQYUBc7kVThzGZmbe6Ws%2BC8Pg9PIPmeyNQZKVE5j4RFdDa74bhsqh8pvvwselV9J5MZ958NQejPxo4UOX58bXkLQIq3AZkI1H7o0Wqvgb7LbGBdSm4eddyTmJa7%2Bxm0ZgNRhdFf","locale":"en-US","buyingOptionType":"USED","aapiBuyingOptionIndex":1}],"desktop_buybox_group_2":[{"displayPrice":"$8.99","priceAmount":8.99,"currencySymbol":"$","integerValue":"8","decimalSeparator":".","fractionalValue":"99","symbolPosition":"left","hasSpace":false,"showFractionalPartIfEmpty":true,"offerListingId":"FPAgLD8jls34W7ARk0Aginh57a4wfKPHs%2FH1cJNhB07JrJLEFV65U373D8W3yJP6GyX2EvrpIWhVkR0wt3XoQNMM8gcACaHqFKaDcmUBfrep1QcAJl6rfzkcV0W71ThL23p7A6BsmaA%3D","locale":"en-US","buyingOptionType":"PICKUP","aapiBuyingOptionIndex":2}]}

### Purchase options and add-ons

American Buffalo, which won both the Drama Critics Circle Award for the best American play and the Obie Award, is considered a classic of the American theater. Newsweek acclaimed Mamet as the “hot young American playwright . . . someone to watch.” The New York Times exclaimed in admiration: “The man can write!” Other critics called the play “a sizzler,” ‘super,” and ‘dynamite.”

Now from Gregory Mosher, the producer of the original stage production, comes a stunning screen adaptation, directed by Michael Corrente and starring Dustin Hoffman, Dennis Franz, and Sean Nelson.

A classic tragedy, American Buffalo is the story of three men struggling in the pursuit of their distorted vision of the American Dream. By turns touching and cynical, poignant and violent, American Buffalo is a piercing story of how people can be corrupted into betraying their ideals and those they love.

Read more
Report an issue with this product or seller

Previous slide of product details

1. Print length
   106 pages
2. Language
   English
3. Publisher
   Grove Press
4. Publication date
   January 11, 1994
5. Dimensions
   5.4 x 0.4 x 8.1 inches
6. ISBN-10
   0802150578
7. ISBN-13
   978-0802150578
8. Lexile measure
   NP
9. See all details

Next slide of product details

Sponsored

## Frequently bought together

###

This item: American Buffalo
$8.99$8.99
Get it as soon as Monday, Dec 30
In Stock
Ships from and sold by Amazon.com.
+
Glengarry Glen Ross: A Play
$10.19$10.19
Get it as soon as Monday, Dec 30
In Stock
Ships from and sold by Amazon.com.
+
Oleanna: A Play
$13.23$13.23
Get it as soon as Friday, Dec 27
In Stock
Ships from and sold by Amazon.com.
Total price: $32.41$32.41
To see our price, add these items to your cart.
Try again!
Details
Added to Cart
spCSRF_Treatment
Add all 3 to Cart
Choose items to buy together.

## Customers who viewed this item also viewed

Page 1 of 1 Start over Page 1 of 1
Previous set of slides

1. Glengarry Glen Ross: A Play
   David Mamet
   4.4 out of 5 stars 345
   Paperback
   -40%$10.19$10.19
   List: $17.00
   Get it as soon as Monday, Dec 30
   FREE Shipping on orders over $35 shipped by Amazon
2. Oleanna: A Play
   David Mamet
   4.4 out of 5 stars 207
   Paperback
   -22%$13.23$13.23
   List: $17.00
   Get it as soon as Friday, Dec 27
   FREE Shipping on orders over $35 shipped by Amazon
3. American Buffalo: In Search of a Lost Icon
   Steven Rinella
   4.8 out of 5 stars 4,715
   Paperback
   #1 Best Seller
   in Biology of Mammals
   -42%$11.69$11.69
   List: $20.00
   Get it as soon as Friday, Dec 27
   FREE Shipping on orders over $35 shipped by Amazon
4. American Buffalo
   David Mamet
   4.6 out of 5 stars 50
   Paperback
   $15.95$15.95
   Get it as soon as Friday, Dec 27
   FREE Shipping on orders over $35 shipped by Amazon
5. Speed-the-plow: A play (acting edition)
   David Mamet
   4.5 out of 5 stars 57
   Paperback
   $15.95$15.95
   Get it as soon as Monday, Dec 30
   FREE Shipping on orders over $35 shipped by Amazon
   Only 3 left in stock (more on the way).
6. Plays
   david-mamet
   4.9 out of 5 stars 20
   Paperback
   $33.53$33.53
   Get it as soon as Tuesday, Dec 31
   FREE Shipping on orders over $35 shipped by Amazon
   Only 1 left in stock (more on the way).

Next set of slides

## Similar items that ship from close to you

Page 1 of 1 Start over Page 1 of 1
Previous set of slides

1. American Buffalo: In Search of a Lost Icon
   Steven Rinella
   4.8 out of 5 stars 4,715
   Paperback
   #1 Best Seller
   in Biology of Mammals
   -42%$11.69$11.69
   List: $20.00
   Get it as soon as Friday, Dec 27
   FREE Shipping on orders over $35 shipped by Amazon
2. Waiting for Godot: A Tragicomedy in Two Acts (Beckett, Samuel)
   Samuel Beckett
   4.3 out of 5 stars 1,973
   Paperback
   -35%$10.43$10.43
   List: $16.00
   Get it as soon as Friday, Dec 27
   FREE Shipping on orders over $35 shipped by Amazon

Next set of slides

## Product details

- Publisher ‏ : ‎ Grove Press; Subsequent edition (January 11, 1994)
- Language ‏ : ‎ English
- Paperback ‏ : ‎ 106 pages
- ISBN-10 ‏ : ‎ 0802150578
- ISBN-13 ‏ : ‎ 978-0802150578
- Lexile measure ‏ : ‎ NP
- Item Weight ‏ : ‎ 5.5 ounces
- Dimensions ‏ : ‎ 5.4 x 0.4 x 8.1 inches

- Best Sellers Rank: #376,058 in Books (See Top 100 in Books)
  - #247 in American Dramas & Plays
  - #864 in Theater (Books)

- Customer Reviews:
  4.2 4.2 out of 5 stars 101 ratings

Brief content visible, double tap to read full content.
Full content visible, double tap to read brief content.

## Videos

Help others learn more about this product by uploading a video!
Upload your video

## About the author

Follow authors to get new release updates, plus improved recommendations.
Follow

## David Mamet

Brief content visible, double tap to read full content.
Full content visible, double tap to read brief content.

David Mamet's numerous plays include Oleanna, Glengarry Glen Ross (winner of the Pulitzer Prize and the New York Drama Critics' Circle Award), American Buffalo, Speed-the-Plow, Boston Marriage, November, Race and The Anarchist. He wrote the screenplays for such films as The Verdict, The Untouchables and Wag the Dog, and has twice been nominated for an Academy Award. He has written and directed ten films, including Homicide, The Spanish Prisoner, State and Main, House of Games, Spartan and Redbelt. In addition, he wrote the novels The Village, The Old Religion, Wilson and many books of nonfiction, including Bambi vs. Godzilla: On the Nature, Purpose and Practice of the Movie Business; Theatre; Three Uses of the Knife: On the Nature and Purpose of Drama and the New York Times bestseller The Secret Knowledge: On the Dismantling of American Culture. His HBO film Phil Spector, starring Al Pacino and Helen Mirren, aired in 2013 and earned him two Emmy Award nominations for Outstanding Writing and Outstanding Directing. He was co-creator and executive producer of the CBS television show The Unit and is a founding member of the Atlantic Theater Company.

## Related products with free delivery on eligible orders

Page 1 of 1 Start over Page 1 of 1
Sponsored
| Try Prime for unlimited fast, free shipping
Previous page of related Sponsored Products

1. Feedback
   Buffalo Bill Cody: An Autobiography
   Buffalo Bill Cody
   218
   Paperback
   $8.95$8.95
2. Feedback
   Macbeth (Shakespeare Library)
   William Shakespeare
   13
   Paperback
   $21.99$21.99
3. Feedback
   Venus and Adonis (Shakespeare Library)
   William Shakespeare
   16
   Paperback
   $13.85$13.85
4. Feedback
   Study Guide: American Buffalo by David Mamet (SuperSummary)
   SuperSummary
   Paperback
   $11.95$11.95
5. Feedback
   Clinically Un-Depressed
   Will Holcomb
   Plays that matter. Clinically Un-Depressed is funny and powerful. Entertains but doesn't preach.
   26
   Paperback
   $12.00$12.00
6. Feedback
   The Winter's Tale (Shakespeare Library)
   William Shakespeare
   837
   Paperback
   $20.99$20.99
7. Feedback
   Hamlet (Shakespeare Library)
   William Shakespeare
   220
   Paperback
   $31.99$31.99
8. Feedback
   Shakespeare's Comedy of A Midsummer-Night's Dream - Illustrated by W. Heath Robinson
   William Shakespeare
   13
   Paperback
   $41.99$41.99
9. Feedback
   Richard III (Shakespeare Library)
   William Shakespeare
   131
   Paperback
   $30.99$30.99
10. Feedback
    Twelfth Night (Shakespeare Library)
    William Shakespeare
    3,381
    Paperback
    $14.24$14.24

Next page of related Sponsored Products

Sponsored

# How would you rate your experience shopping for books on Amazon today?

Very poor | Poor | Neutral | Good | Great
Very poor |  | Neutral |  | Great

# Thank you for your feedback!

## Customer reviews

4.2 out of 5 stars
4.2 out of 5
101 global ratings

- 5 star4 star3 star2 star1 star5 star
  55%22%16%6%1%55%
- 5 star4 star3 star2 star1 star4 star
  55%22%16%6%1%22%
- 5 star4 star3 star2 star1 star3 star
  55%22%16%6%1%16%
- 5 star4 star3 star2 star1 star2 star
  55%22%16%6%1%6%
- 5 star4 star3 star2 star1 star1 star
  55%22%16%6%1%1%

How customer reviews and ratings work

Customer Reviews, including Product Star Ratings help customers to learn more about the product and decide whether it is the right product for them.

To calculate the overall star rating and percentage breakdown by star, we don’t use a simple average. Instead, our system considers things like how recent a review is and if the reviewer bought the item on Amazon. It also analyzed reviews to verify trustworthiness.

Learn more how customers reviews work on Amazon

### Review this product

Share your thoughts with other customers
Write a customer review

Sponsored

### Customers say

Customers find the play to be a classic drama with engaging dialogue. They describe the dialogue as searing and crackling, drawing them in. The play is described as one of the best American plays.

AI-generated from the text of customer reviews

Select to learn more
Play quality
Dialogue quality
5 customers mention "Play quality"5 positive0 negative

Customers enjoy the play's quality. They find it to be a great classic drama and one of the best American plays.

"Superb play, written by one of the masters of our time (though not the most important person on Broadway - George Lane takes that win in my estimate)..." Read more

"One of the best American plays." Read more

"One of the most important plays to come out of the American theater landscape in the latter part of the 20th Century - as it is said in the..." Read more

"Good overall!" Read more

3 customers mention "Dialogue quality"3 positive0 negative

Customers enjoy the dialogue quality. They find the monologues great and the dialogue fast-paced. The plays draw them in and make it difficult to put down.

"This is a classic of contemporary drama. The dialogue crackles by, like machine gun fire, and there are some great monologues!..." Read more

"...Featuring His signature searing Dialogue. His plays draw you in and you don't want to put it down...." Read more

"...different, but it is still in great condition and even has notes from the playwright! Thank you!!" Read more

View Image Gallery
Amazon Customer
5.0 out of 5 stars
Images in this review

- Sort by reviews type
  Top reviews

### Top reviews from the United States

#### There was a problem filtering reviews right now. Please try again later.

- bluesbro1

  ##### 5.0 out of 5 stars Great Classic Drama!

  Reviewed in the United States on September 3, 2022
  Verified Purchase
  This is a classic of contemporary drama. The dialogue crackles by, like machine gun fire, and there are some great monologues! The monologue where he complains about a woman friend begrudging him a leftover piece of toast in a diner, is hilarious!
  Read more
  Helpful
  Report
- Kindle Customer

  ##### 4.0 out of 5 stars Minimalistic

  Reviewed in the United States on February 20, 2022
  Verified Purchase
  Minimalistic to a fault.
  Although action is discussed, very little action actually occurs, and the action that does occur is anticlimactic in terms of the plot.
  Three actors only with a few other characters who are never present but much discussed.
  All these things are common examples of this genre of play. What we have here is not all that different from an older play like Waiting For Godot. Furthermore, without spoiling the ending, this firecracker hardly pops. Leaving the audience to wonder whether Bob is really being taken to the hospital. I'd of preferred a concrete ending one way or the other. The big theme of the play which is extracted from say poker is this knot where business and friendship are tangled together. Now you have Don, right? And you have his business partner Teach and his friend, Bob. Well, the way Teach and Bob operate on two different levels is reflected in the way there has been cheating at the poker games.
  Read more
  Helpful
  Report
- Jason Ilgenfritz

  ##### 5.0 out of 5 stars Exactly as Described

  Reviewed in the United States on August 3, 2013
  Verified Purchase
  Superb play, written by one of the masters of our time (though not the most important person on Broadway - George Lane takes that win in my estimate). Book in great condition. Something I'd recommend to anyone.
  Read more
  Helpful
  Report
- Michael G.

  ##### 3.0 out of 5 stars A play in two acts.

  Reviewed in the United States on November 27, 2016
  Three male characters, none of whom are likely candidates for admission to MENSA anytime soon. A customerless junkshop is the play's only set.
  David Mamet exposes insights into the human condition through the pedestrian, though paradoxically engaging, dialogue of American Buffalo's characters. Men of limited intelligence and unlimited guilelessness.
  A classic drama that cuts to the emotional core without extraneous fuss or muss. Minimalist entertainment.
  Read more
  Helpful
  Report
- scott

  ##### 5.0 out of 5 stars clean condition

  Reviewed in the United States on July 7, 2022
  Verified Purchase
  perfect brand new condition thank you
  Read more
  Helpful
  Report
- Edward Stonelight

  ##### 5.0 out of 5 stars Five Stars

  Reviewed in the United States on August 12, 2017
  Verified Purchase
  One of the best American plays.
  Read more
  Helpful
  Report
- Cipriano

  ##### 4.0 out of 5 stars David Mamet is Brilliant!

  Reviewed in the United States on August 23, 2020
  Verified Purchase
  I recently became interested in David Mamet and his writings, and this one easily ranks among his best. Featuring His signature searing Dialogue. His plays draw you in and you don't want to put it down. Don't be surprised if you finish this in record time.
  Read more
  One person found this helpful
  Helpful
  Report
- W. Cole

  ##### 2.0 out of 5 stars 2 Stars for the Product - 5+ for the Writing

  Reviewed in the United States on September 16, 2017
  Verified Purchase
  One of the most important plays to come out of the American theater landscape in the latter part of the 20th Century - as it is said in the introduction: "the iambic pentameter of our time". Unfortunately, the amazing ebb and flow of the writing is littered with typos and misspellings. The character 'Teach' for example somehow becomes 'Retch'. If I was Mamet I would be suing the publisher for libel . . . or slander or both. I got the Kindle edition for about 9 bucks. Given the horrid production errors, it may have been worth 'two fiddy'.
  Read more
  One person found this helpful
  Helpful
  Report

### Top reviews from other countries

Translate all reviews to English

- Caio Leao

  ##### 5.0 out of 5 stars mamet no seu melhor.

  Reviewed in Brazil on April 1, 2019
  Verified Purchase
  Linda peça.
  Read more
  Report
  Translate review to English
- LF

  ##### 4.0 out of 5 stars Très bon état, mais pas ma tasse de thé!

  Reviewed in France on August 9, 2013
  Verified Purchase
  Le livre en lui même était parfait, sans accro ni rien du tout. Livré dans les temps. Mais l'histoire en elle-même n'a pas vraiment de sens et ce livre contient beaucoup de gros mots en anglais. Bref, ce n'est pas mon genre de livre!
  Read more
  Report
  Translate review to English
- Client d'Amazon

  ##### 4.0 out of 5 stars Four Stars

  Reviewed in Canada on August 6, 2016
  Verified Purchase
  Good book, good quality
  Read more
  Report

Processing...

Your recently viewed items and featured recommendations